aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/search/AbstractSearchAlgorithm.py
diff options
context:
space:
mode:
Diffstat (limited to 'resources/libraries/python/search/AbstractSearchAlgorithm.py')
-rw-r--r--resources/libraries/python/search/AbstractSearchAlgorithm.py12
1 files changed, 7 insertions, 5 deletions
diff --git a/resources/libraries/python/search/AbstractSearchAlgorithm.py b/resources/libraries/python/search/AbstractSearchAlgorithm.py
index 08f3a6bebc..538322a42c 100644
--- a/resources/libraries/python/search/AbstractSearchAlgorithm.py
+++ b/resources/libraries/python/search/AbstractSearchAlgorithm.py
@@ -21,20 +21,22 @@ class AbstractSearchAlgorithm(object):
__metaclass__ = ABCMeta
- def __init__(self, rate_provider):
+ def __init__(self, measurer):
"""Store the rate provider.
:param rate_provider: Object able to perform trial measurements.
:type rate_provider: AbstractRateProvider
"""
- # TODO: Type check for AbstractRateProvider?
- self.rate_provider = rate_provider
+ # TODO: Type check for AbstractMeasurer?
+ self.measurer = measurer
@abstractmethod
def narrow_down_ndr_and_pdr(
self, fail_rate, line_rate, packet_loss_ratio):
"""Perform measurements to narrow down intervals, return them.
+ This will be renamed when custom loss ratio lists are supported.
+
:param fail_rate: Minimal target transmit rate [pps].
:param line_rate: Maximal target transmit rate [pps].
:param packet_loss_ratio: Fraction of packets lost, for PDR [1].
@@ -21,20 +21,22 @@ class AbstractSearchAlgorithm(object):
"""Store the rate provider.
- :param rate_provider: Object able to perform trial measurements.
- :type rate_provider: AbstractRateProvider
+ :param measurer: Object able to perform trial or composite measurements.
+ :type measurer: AbstractMeasurer
"""